@@ -23,7 +23,7 @@ use strict;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -152,7 +152,7 @@ sub delete_expired
 {
  my $self=shift;
  my $now=Net::DRI::Util::microtime();
- my $c=$self->{c};
+ my $c=$self->{data};
  while(my ($type,$c1)=each(%$c))
  {
   while(my ($key,$c2)=each(%{$c1}))
@@ -162,5 +162,11 @@ sub delete_expired
  }
 }
 
+sub delete
+{
+ my $self=shift;
+ $self->{data}={};
+}
+
 ##############################################################################
 1;
