@@ -22,7 +22,7 @@ use strict;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 our $NS='urn:ietf:params:xml:ns:rgp-1.0';
 
 =pod
@@ -79,6 +79,11 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'rgp' => [] }};
+}
+
 ##################################################################################################
 
 ########### Query commands
