@@ -22,7 +22,7 @@ use strict;
 use Time::HiRes ();
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.7 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -65,7 +65,9 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 
-#######################################################################################################
+####################################################################################################
+
+our %CCA2=map { $_ => 1 } qw/AF AX AL DZ AS AD AO AI AQ AG AR AM AW AU AT AZ BS BH BD BB BY BE BZ BJ BM BT BO BA BW BV BR IO BN BG BF BI KH CM CA CV KY CF TD CL CN CX CC CO KM CG CD CK CR CI HR CU CY CZ DK DJ DM DO EC EG SV GQ ER EE ET FK FO FJ FI FR GF PF TF GA GM GE DE GH GI GR GL GD GP GU GT GN GW GY HT HM HN HK HU IS IN ID IR IQ IE IL IT JM JP JO KZ KE KI KP KR KW KG LA LV LB LS LR LY LI LT LU MO MK MG MW MY MV ML MT MH MQ MR MU YT MX FM MD MC MN MS MA MZ MM NA NR NP NL AN NC NZ NI NE NG NU NF MP NO OM PK PW PS PA PG PY PE PH PN PL PT PR QA RE RO RU RW SH KN LC PM VC WS SM ST SA SN CS SC SL SG SK SI SB SO ZA GS ES LK SD SR SJ SZ SE CH SY TW TJ TZ TH TL TG TK TO TT TN TR TM TC TV UG UA AE GB US UM UY UZ VU VA VE VN VG VI WF EH YE ZM ZW/;
 
 sub all_valid
 {
@@ -76,7 +78,22 @@ sub all_valid
  return 1;
 }
 
-#############################################################################################
+sub hash_merge
+{
+ my ($rmaster,$rtoadd)=@_;
+ while(my ($k,$v)=each(%$rtoadd))
+ {
+  $rmaster->{$k}={} unless exists($rmaster->{$k});
+  while(my ($kk,$vv)=each(%$v))
+  {
+   $rmaster->{$k}->{$kk}=[] unless exists($rmaster->{$k}->{$kk});
+   my @t=@$vv;
+   push @{$rmaster->{$k}->{$kk}},\@t;
+  }
+ }
+}
+
+####################################################################################################
 
 sub isint
 {
